@@ -1,5 +1,5 @@
 /*
- *   Copyright (C) 2009-2013 Erwin Waterlander
+ *   Copyright (C) 2009-2014 Erwin Waterlander
  *   All rights reserved.
  *
  *   Redistribution and use in source and binary forms, with or without
@@ -55,7 +55,23 @@
  * returns 1 on success, 0 when it fails.
  *
  ******************************************************************/
-int symbolic_link(char *path)
+
+#if (defined(_WIN32) && !defined(__CYGWIN__))
+
+int symbolic_link(const char *path)
+{
+   DWORD attrs;
+
+   attrs = GetFileAttributes(path);
+
+   if (attrs == INVALID_FILE_ATTRIBUTES)
+      return(0);
+
+   return ((attrs & FILE_ATTRIBUTE_REPARSE_POINT) != 0);
+}
+
+#else
+int symbolic_link(const char *path)
 {
 #ifdef S_ISLNK
    struct stat buf;
@@ -68,6 +84,7 @@ int symbolic_link(char *path)
 #endif
    return(0);
 }
+#endif
 
 /******************************************************************
  *
@@ -166,7 +183,7 @@ int regfile_target(char *path, CFlag *ipFlag, char *progname)
 
 void PrintBSDLicense(void)
 {
-  fprintf(stderr, "%s", _("\
+  printf("%s", _("\
 Redistribution and use in source and binary forms, with or without\n\
 modification, are permitted provided that the following conditions\n\
 are met:\n\
@@ -175,7 +192,8 @@ are met:\n\
 2. Redistributions in binary form must reproduce the above copyright\n\
    notice in the documentation and/or other materials provided with\n\
    the distribution.\n\n\
-\
+"));
+  printf("%s", _("\
 THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY\n\
 EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE\n\
 IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR\n\
@@ -192,104 +210,108 @@ IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.\n\
 
 void PrintUsage(char *progname)
 {
-  fprintf(stderr, _("\
-%s %s (%s)\n\
-Usage: %s [options] [file ...] [-n infile outfile ...]\n\
- -ascii                convert only line breaks (default)\n\
- -iso                  conversion between DOS and ISO-8859-1 character set\n\
-   -1252               Use Windows code page 1252 (Western European)\n\
-   -437                Use DOS code page 437 (US) (default)\n\
-   -850                Use DOS code page 850 (Western European)\n\
-   -860                Use DOS code page 860 (Portuguese)\n\
-   -863                Use DOS code page 863 (French Canadian)\n\
-   -865                Use DOS code page 865 (Nordic)\n\
- -7                    Convert 8 bit characters to 7 bit space\n\
- -c, --convmode        conversion mode\n\
-   convmode            ascii, 7bit, iso, mac, default to ascii\n\
- -f, --force           force conversion of binary files\n\
- -h, --help            give this help\n\
- -k, --keepdate        keep output file date\n\
- -L, --license         display software license\n\
- -l, --newline         add additional newline\n\
- -m, --add-bom         add UTF-8 Byte Order Mark\n\
- -n, --newfile         write to new file\n\
-   infile              original file in new file mode\n\
-   outfile             output file in new file mode\n\
- -o, --oldfile         write to old file (default)\n\
-   file ...            files to convert in old file mode\n\
- -q, --quiet           quiet mode, suppress all warnings\n\
-                       always on in stdio mode\n\
- -s, --safe            skip binary files (default)\n"),
- progname, VER_REVISION, VER_DATE, progname);
+  printf(_("Usage: %s [options] [file ...] [-n infile outfile ...]\n"), progname);
+  printf(_(" -ascii                convert only line breaks (default)\n"));
+  printf(_(" -iso                  conversion between DOS and ISO-8859-1 character set\n"));
+  printf(_("   -1252               use Windows code page 1252 (Western European)\n"));
+  printf(_("   -437                use DOS code page 437 (US) (default)\n"));
+  printf(_("   -850                use DOS code page 850 (Western European)\n"));
+  printf(_("   -860                use DOS code page 860 (Portuguese)\n"));
+  printf(_("   -863                use DOS code page 863 (French Canadian)\n"));
+  printf(_("   -865                use DOS code page 865 (Nordic)\n"));
+  printf(_(" -7                    convert 8 bit characters to 7 bit space\n"));
+  if ((strncmp(progname, "dos2unix", sizeof("mac2unix")) == 0) || (strncmp(progname, "dos2unix", sizeof("dos2unix")) == 0))
+    printf(_(" -b, --keep-bom        keep Byte Order Mark\n"));
+  else
+    printf(_(" -b, --keep-bom        keep Byte Order Mark (default)\n"));
+  printf(_(" -c, --convmode        conversion mode\n\
+   convmode            ascii, 7bit, iso, mac, default to ascii\n"));
+  printf(_(" -f, --force           force conversion of binary files\n"));
+  printf(_(" -h, --help            display this help text\n"));
+  printf(_(" -k, --keepdate        keep output file date\n"));
+  printf(_(" -L, --license         display software license\n"));
+  printf(_(" -l, --newline         add additional newline\n"));
+  printf(_(" -m, --add-bom         add UTF-8 Byte Order Mark\n"));
+  printf(_(" -n, --newfile         write to new file\n\
+   infile              original file in new-file mode\n\
+   outfile             output file in new-file mode\n"));
+  printf(_(" -o, --oldfile         write to old file (default)\n\
+   file ...            files to convert in old-file mode\n"));
+  printf(_(" -q, --quiet           quiet mode, suppress all warnings\n\
+                         (always on in stdio mode)\n"));
+  if ((strncmp(progname, "dos2unix", sizeof("mac2unix")) == 0) || (strncmp(progname, "dos2unix", sizeof("dos2unix")) == 0))
+    printf(_(" -r, --remove-bom      remove Byte Order Mark (default)\n"));
+  else
+    printf(_(" -r, --remove-bom      remove Byte Order Mark\n"));
+  printf(_(" -s, --safe            skip binary files (default)\n"));
 #ifdef D2U_UNICODE
-  fprintf(stderr, _("\
- -ul, --assume-utf16le Assume that the input format is UTF-16LE\n\
- -ub, --assume-utf16be Assume that the input format is UTF-16BE\n"));
+  printf(_(" -ul, --assume-utf16le assume that the input format is UTF-16LE\n"));
+  printf(_(" -ub, --assume-utf16be assume that the input format is UTF-16BE\n"));
 #endif
 #ifdef S_ISLNK
-  fprintf(stderr, _("\
- -F, --follow-symlink  follow symbolic links and convert the targets\n\
- -R, --replace-symlink replace symbolic links with converted files\n\
-                       (original target files remain unchanged)\n\
- -S, --skip-symlink    keep symbolic links and targets unchanged (default)\n"));
+  printf(_(" -F, --follow-symlink  follow symbolic links and convert the targets\n"));
 #endif
-  fprintf(stderr, _("\
- -V, --version         display version number\n"));
+#if defined(S_ISLNK) || (defined(_WIN32) && !defined(__CYGWIN__))
+  printf(_(" -R, --replace-symlink replace symbolic links with converted files\n\
+                         (original target files remain unchanged)\n"));
+  printf(_(" -S, --skip-symlink    keep symbolic links and targets unchanged (default)\n"));
+#endif
+  printf(_(" -V, --version         display version number\n"));
 }
 
 #define MINGW32_W64 1
 
 void PrintVersion(char *progname)
 {
-  fprintf(stderr, "%s %s (%s)\n", progname, VER_REVISION, VER_DATE);
+  printf("%s %s (%s)\n", progname, VER_REVISION, VER_DATE);
 #if DEBUG
-  fprintf(stderr, "VER_AUTHOR: %s\n", VER_AUTHOR);
+  printf("VER_AUTHOR: %s\n", VER_AUTHOR);
 #endif
 #if defined(__WATCOMC__) && defined(__I86__)
-  fprintf(stderr, "%s", _("DOS 16 bit version (WATCOMC).\n"));
+  printf("%s", _("DOS 16 bit version (WATCOMC).\n"));
 #elif defined(__TURBOC__) && defined(__MSDOS__)
-  fprintf(stderr, "%s", _("DOS 16 bit version (TURBOC).\n"));
+  printf("%s", _("DOS 16 bit version (TURBOC).\n"));
 #elif defined(__WATCOMC__) && defined(__DOS__)
-  fprintf(stderr, "%s", _("DOS 32 bit version (WATCOMC).\n"));
+  printf("%s", _("DOS 32 bit version (WATCOMC).\n"));
 #elif defined(__DJGPP__)
-  fprintf(stderr, "%s", _("DOS 32 bit version (DJGPP).\n"));
+  printf("%s", _("DOS 32 bit version (DJGPP).\n"));
 #elif defined(__MSYS__)
-  fprintf(stderr, "%s", _("MSYS version.\n"));
+  printf("%s", _("MSYS version.\n"));
 #elif defined(__CYGWIN__)
-  fprintf(stderr, "%s", _("Cygwin version.\n"));
+  printf("%s", _("Cygwin version.\n"));
 #elif defined(__WIN64__) && defined(__MINGW64__)
-  fprintf(stderr, "%s", _("Windows 64 bit version (MinGW-w64).\n"));
+  printf("%s", _("Windows 64 bit version (MinGW-w64).\n"));
 #elif defined(__WATCOMC__) && defined(__NT__)
-  fprintf(stderr, "%s", _("Windows 32 bit version (WATCOMC).\n"));
+  printf("%s", _("Windows 32 bit version (WATCOMC).\n"));
 #elif defined(_WIN32) && defined(__MINGW32__) && (D2U_COMPILER == MINGW32_W64)
-  fprintf(stderr, "%s", _("Windows 32 bit version (MinGW-w64).\n"));
+  printf("%s", _("Windows 32 bit version (MinGW-w64).\n"));
 #elif defined(_WIN32) && defined(__MINGW32__)
-  fprintf(stderr, "%s", _("Windows 32 bit version (MinGW).\n"));
+  printf("%s", _("Windows 32 bit version (MinGW).\n"));
 #elif defined(_WIN64) && defined(_MSC_VER)
-  fprintf(stderr,_("Windows 64 bit version (MSVC %d).\n"),_MSC_VER);
+  printf(_("Windows 64 bit version (MSVC %d).\n"),_MSC_VER);
 #elif defined(_WIN32) && defined(_MSC_VER)
-  fprintf(stderr,_("Windows 32 bit version (MSVC %d).\n"),_MSC_VER);
+  printf(_("Windows 32 bit version (MSVC %d).\n"),_MSC_VER);
 #elif defined (__OS2__) && defined(__WATCOMC__) /* OS/2 Warp */
-  fprintf(stderr, "%s", _("OS/2 version (WATCOMC).\n"));
+  printf("%s", _("OS/2 version (WATCOMC).\n"));
 #elif defined (__OS2__) && defined(__EMX__) /* OS/2 Warp */
-  fprintf(stderr, "%s", _("OS/2 version (EMX).\n"));
+  printf("%s", _("OS/2 version (EMX).\n"));
 #endif
 #ifdef D2U_UNICODE
-  fprintf(stderr, "%s", _("With Unicode UTF-16 support.\n"));
+  printf("%s", _("With Unicode UTF-16 support.\n"));
 #else
-  fprintf(stderr, "%s", _("Without Unicode UTF-16 support.\n"));
+  printf("%s", _("Without Unicode UTF-16 support.\n"));
 #endif
 #ifdef ENABLE_NLS
-  fprintf(stderr, "%s", _("With native language support.\n"));
+  printf("%s", _("With native language support.\n"));
 #else
-  fprintf(stderr, "%s", "Without native language support.\n");
+  printf("%s", "Without native language support.\n");
 #endif
 }
 
 #ifdef ENABLE_NLS
 void PrintLocaledir(char *localedir)
 {
-  fprintf(stderr, "LOCALEDIR: %s\n", localedir);
+  printf("LOCALEDIR: %s\n", localedir);
 }
 #endif
 
