@@ -7,8 +7,8 @@
  *  The dos2unix package is distributed under FreeBSD style license.
  *  See also http://www.freebsd.org/copyright/freebsd-license.html
  *  --------
- * 
- *  Copyright (C) 2009-2012 Erwin Waterlander
+ *
+ *  Copyright (C) 2009-2014 Erwin Waterlander
  *  Copyright (C) 1994-1995 Benjamin Lin.
  *  All rights reserved.
  *
@@ -56,15 +56,15 @@
 #include "unix2dos.h"
 #include "querycp.h"
 #ifdef D2U_UNICODE
-#ifndef MSDOS  /* Unix, Cygwin */
+#if !defined(__MSDOS__) && !defined(_WIN32) && !defined(__OS2__)  /* Unix, Cygwin */
 # include <langinfo.h>
 #endif
 #endif
 
 void PrintLicense(void)
 {
-  fprintf(stderr, "%s", _("\
-Copyright (C) 2009-2012 Erwin Waterlander\n\
+  printf("%s", _("\
+Copyright (C) 2009-2014 Erwin Waterlander\n\
 Copyright (C) 1994-1995 Benjamin Lin\n\
 All rights reserved.\n\n"));
   PrintBSDLicense();
@@ -104,6 +104,8 @@ int ConvertUnixToDosW(FILE* ipInF, FILE* ipOutF, CFlag *ipFlag, char *progname)
     int RetVal = 0;
     wint_t TempChar;
     wint_t PreviousChar = 0;
+    int line_nr = 1;
+    char *errstr;
 
     ipFlag->status = 0;
 
@@ -124,15 +126,20 @@ int ConvertUnixToDosW(FILE* ipInF, FILE* ipOutF, CFlag *ipFlag, char *progname)
               (TempChar != 0x0c)) {  /* Not a form feed */
             RetVal = -1;
             ipFlag->status |= BINARY_FILE ;
+            if (!ipFlag->Quiet)
+            {
+              fprintf(stderr, "%s: ", progname);
+              fprintf(stderr, _("Binary symbol 0x00%02X found at line %d\n"),TempChar, line_nr);
+            }
             break;
           }
           if (TempChar == 0x0a)
           {
-            d2u_putwc(0x0d, ipOutF, ipFlag); /* got LF, put CR */
+            d2u_putwc(0x0d, ipOutF, ipFlag); /* got LF, put extra CR */
           } else {
              if (TempChar == 0x0d) /* got CR */
              {
-               if ((TempChar = d2u_getwc(ipInF, ipFlag->bomtype)) == WEOF) /* get next char */
+               if ((TempChar = d2u_getwc(ipInF, ipFlag->bomtype)) == WEOF) /* get next char (possibly LF) */
                  TempChar = 0x0d;  /* Read error, or end of file. */
                else
                {
@@ -141,6 +148,8 @@ int ConvertUnixToDosW(FILE* ipInF, FILE* ipOutF, CFlag *ipFlag, char *progname)
                }
              }
           }
+          if (TempChar == 0x0a) /* Count all DOS and Unix line breaks */
+            ++line_nr;
           if (d2u_putwc(TempChar, ipOutF, ipFlag) == WEOF)
           {
               RetVal = -1;
@@ -148,8 +157,9 @@ int ConvertUnixToDosW(FILE* ipInF, FILE* ipOutF, CFlag *ipFlag, char *progname)
               {
                 if (!(ipFlag->status & UNICODE_CONVERSION_ERROR))
                 {
+                  errstr = strerror(errno);
                   fprintf(stderr, "%s: ", progname);
-                  fprintf(stderr, "%s", _("can not write to output file\n"));
+                  fprintf(stderr, _("can not write to output file: %s\n"), errstr);
                 }
               }
               break;
@@ -169,6 +179,11 @@ int ConvertUnixToDosW(FILE* ipInF, FILE* ipOutF, CFlag *ipFlag, char *progname)
               (TempChar != 0x0c)) {  /* Not a form feed */
             RetVal = -1;
             ipFlag->status |= BINARY_FILE ;
+            if (!ipFlag->Quiet)
+            {
+              fprintf(stderr, "%s: ", progname);
+              fprintf(stderr, _("Binary symbol 0x00%02X found at line %d\n"),TempChar, line_nr);
+            }
             break;
           }
           if ((TempChar != 0x0a)) /* Not an LF */
@@ -179,8 +194,9 @@ int ConvertUnixToDosW(FILE* ipInF, FILE* ipOutF, CFlag *ipFlag, char *progname)
                 {
                   if (!(ipFlag->status & UNICODE_CONVERSION_ERROR))
                   {
+                    errstr = strerror(errno);
                     fprintf(stderr, "%s: ", progname);
-                    fprintf(stderr, "%s", _("can not write to output file\n"));
+                    fprintf(stderr, _("can not write to output file: %s\n"), errstr);
                   }
                 }
                 break;
@@ -189,6 +205,7 @@ int ConvertUnixToDosW(FILE* ipInF, FILE* ipOutF, CFlag *ipFlag, char *progname)
             }
           else{
             /* TempChar is an LF */
+            ++line_nr;
             /* Don't touch this delimiter if it's a CR,LF pair. */
             if ( PreviousChar == 0x0d ) {
               if (d2u_putwc(0x0a, ipOutF, ipFlag) == WEOF)  /* CR,LF pair. Put LF */
@@ -198,8 +215,9 @@ int ConvertUnixToDosW(FILE* ipInF, FILE* ipOutF, CFlag *ipFlag, char *progname)
                   {
                     if (!(ipFlag->status & UNICODE_CONVERSION_ERROR))
                     {
+                      errstr = strerror(errno);
                       fprintf(stderr, "%s: ", progname);
-                      fprintf(stderr, "%s", _("can not write to output file\n"));
+                      fprintf(stderr, _("can not write to output file: %s\n"), errstr);
                     }
                   }
                   break;
@@ -215,8 +233,9 @@ int ConvertUnixToDosW(FILE* ipInF, FILE* ipOutF, CFlag *ipFlag, char *progname)
                 {
                   if (!(ipFlag->status & UNICODE_CONVERSION_ERROR))
                   {
+                    errstr = strerror(errno);
                     fprintf(stderr, "%s: ", progname);
-                    fprintf(stderr, "%s", _("can not write to output file\n"));
+                    fprintf(stderr, _("can not write to output file: %s\n"), errstr);
                   }
                 }
                 break;
@@ -249,12 +268,16 @@ int ConvertUnixToDos(FILE* ipInF, FILE* ipOutF, CFlag *ipFlag, char *progname)
     int TempChar;
     int PreviousChar = 0;
     int *ConvTable;
+    int line_nr = 1;
+    char *errstr;
 
     ipFlag->status = 0;
 
     switch (ipFlag->ConvMode)
     {
       case CONVMODE_ASCII: /* ascii */
+      case CONVMODE_UTF16LE: /* Assume UTF-16LE, bomtype = FILE_UTF8 */
+      case CONVMODE_UTF16BE: /* Assume UTF-16BE, bomtype = FILE_UTF8 */
         ConvTable = U2DAsciiTable;
         break;
       case CONVMODE_7BIT: /* 7bit */
@@ -305,15 +328,20 @@ int ConvertUnixToDos(FILE* ipInF, FILE* ipOutF, CFlag *ipFlag, char *progname)
               (TempChar != '\x0c')) {  /* Not a form feed */
             RetVal = -1;
             ipFlag->status |= BINARY_FILE ;
+            if (!ipFlag->Quiet)
+            {
+              fprintf(stderr, "%s: ", progname);
+              fprintf(stderr, _("Binary symbol 0x%02X found at line %d\n"),TempChar, line_nr);
+            }
             break;
           }
           if (TempChar == '\x0a')
           {
-            fputc('\x0d', ipOutF); /* got LF, put CR */
+            fputc('\x0d', ipOutF); /* got LF, put extra CR */
           } else {
              if (TempChar == '\x0d') /* got CR */
              {
-               if ((TempChar = fgetc(ipInF)) == EOF) /* get next char */
+               if ((TempChar = fgetc(ipInF)) == EOF) /* get next char (possibly LF) */
                  TempChar = '\x0d';  /* Read error, or end of file. */
                else
                {
@@ -322,13 +350,16 @@ int ConvertUnixToDos(FILE* ipInF, FILE* ipOutF, CFlag *ipFlag, char *progname)
                }
              }
           }
-          if (fputc(ConvTable[TempChar], ipOutF) == EOF)
+          if (TempChar == '\x0a') /* Count all DOS and Unix line breaks */
+            ++line_nr;
+          if (fputc(ConvTable[TempChar], ipOutF) == EOF) /* put LF or other char */
           {
               RetVal = -1;
               if (!ipFlag->Quiet)
               {
+                errstr = strerror(errno);
                 fprintf(stderr, "%s: ", progname);
-                fprintf(stderr, "%s", _("can not write to output file\n"));
+                fprintf(stderr, _("can not write to output file: %s\n"), errstr);
               }
               break;
           } else {
@@ -347,6 +378,11 @@ int ConvertUnixToDos(FILE* ipInF, FILE* ipOutF, CFlag *ipFlag, char *progname)
               (TempChar != '\x0c')) {  /* Not a form feed */
             RetVal = -1;
             ipFlag->status |= BINARY_FILE ;
+            if (!ipFlag->Quiet)
+            {
+              fprintf(stderr, "%s: ", progname);
+              fprintf(stderr, _("Binary symbol 0x%02X found at line %d\n"),TempChar, line_nr);
+            }
             break;
           }
           if ((TempChar != '\x0a')) /* Not an LF */
@@ -355,8 +391,9 @@ int ConvertUnixToDos(FILE* ipInF, FILE* ipOutF, CFlag *ipFlag, char *progname)
                 RetVal = -1;
                 if (!ipFlag->Quiet)
                 {
+                  errstr = strerror(errno);
                   fprintf(stderr, "%s: ", progname);
-                  fprintf(stderr, "%s", _("can not write to output file\n"));
+                  fprintf(stderr, _("can not write to output file: %s\n"), errstr);
                 }
                 break;
               }
@@ -364,6 +401,7 @@ int ConvertUnixToDos(FILE* ipInF, FILE* ipOutF, CFlag *ipFlag, char *progname)
             }
           else{
             /* TempChar is an LF */
+            ++line_nr;
             /* Don't touch this delimiter if it's a CR,LF pair. */
             if ( PreviousChar == '\x0d' ) {
               if (fputc('\x0a', ipOutF) == EOF)  /* CR,LF pair. Put LF */
@@ -371,8 +409,9 @@ int ConvertUnixToDos(FILE* ipInF, FILE* ipOutF, CFlag *ipFlag, char *progname)
                   RetVal = -1;
                   if (!ipFlag->Quiet)
                   {
+                    errstr = strerror(errno);
                     fprintf(stderr, "%s: ", progname);
-                    fprintf(stderr, "%s", _("can not write to output file\n"));
+                    fprintf(stderr, _("can not write to output file: %s\n"), errstr);
                   }
                   break;
                 }
@@ -385,8 +424,9 @@ int ConvertUnixToDos(FILE* ipInF, FILE* ipOutF, CFlag *ipFlag, char *progname)
                 RetVal = -1;
                 if (!ipFlag->Quiet)
                 {
+                  errstr = strerror(errno);
                   fprintf(stderr, "%s: ", progname);
-                  fprintf(stderr, "%s", _("can not write to output file\n"));
+                  fprintf(stderr, _("can not write to output file: %s\n"), errstr);
                 }
                 break;
               }
@@ -477,7 +517,7 @@ int ConvertUnixToDosNewFile(char *ipInFN, char *ipOutFN, CFlag *ipFlag, char *pr
     }
     RetVal = -1;
   }
-  
+
 #ifdef NO_MKSTEMP
   if((fd = MakeTempFileFrom(ipOutFN, &TempPath))==NULL) {
 #else
@@ -531,9 +571,15 @@ int ConvertUnixToDosNewFile(char *ipInFN, char *ipOutFN, CFlag *ipFlag, char *pr
   }
 
   InF = read_bom(InF, &ipFlag->bomtype);
+#ifdef D2U_UNICODE
+  if ((ipFlag->bomtype == FILE_MBS) && (ipFlag->ConvMode == CONVMODE_UTF16LE))
+    ipFlag->bomtype = FILE_UTF16LE;
+  if ((ipFlag->bomtype == FILE_MBS) && (ipFlag->ConvMode == CONVMODE_UTF16BE))
+    ipFlag->bomtype = FILE_UTF16BE;
+#endif
 
 #ifdef D2U_UNICODE
-#ifndef MSDOS  /* Unix, Cygwin */
+#if !defined(__MSDOS__) && !defined(_WIN32) && !defined(__OS2__)  /* Unix, Cygwin */
   if ((ipFlag->bomtype == FILE_UTF16LE) || (ipFlag->bomtype == FILE_UTF16BE))
   {
     if (strcmp(nl_langinfo(CODESET), "UTF-8") != 0)
@@ -546,7 +592,7 @@ int ConvertUnixToDosNewFile(char *ipInFN, char *ipOutFN, CFlag *ipFlag, char *pr
     }
   }
 #endif
-#if !defined(WIN32) && !defined(__CYGWIN__) /* Not Windows or Cygwin */
+#if !defined(_WIN32) && !defined(__CYGWIN__) /* Not Windows or Cygwin */
   if ((ipFlag->bomtype == FILE_UTF16LE) || (ipFlag->bomtype == FILE_UTF16BE))
   {
     if (sizeof(wchar_t) < 4)
@@ -560,11 +606,12 @@ int ConvertUnixToDosNewFile(char *ipInFN, char *ipOutFN, CFlag *ipFlag, char *pr
 #endif
 #endif
 
-  if ((ipFlag->add_bom) || (ipFlag->bomtype > 0))
+  if ((ipFlag->add_bom) || ((ipFlag->keep_bom) && (ipFlag->bomtype > 0)))
     fprintf(TempF, "%s", "\xEF\xBB\xBF");  /* UTF-8 BOM */
 
   /* Turn off ISO and 7-bit conversion for Unicode text files */
-  if (ipFlag->bomtype > 0)
+  /* When we assume UTF16, don't change the conversion mode. We need to remember it. */
+  if ((ipFlag->bomtype > 0) && (ipFlag->ConvMode != CONVMODE_UTF16LE) && (ipFlag->ConvMode != CONVMODE_UTF16BE))
     ipFlag->ConvMode = CONVMODE_ASCII;
 
   /* conversion sucessful? */
@@ -592,8 +639,20 @@ int ConvertUnixToDosNewFile(char *ipInFN, char *ipOutFN, CFlag *ipFlag, char *pr
     RetVal = -1;
 
   /* can close output file? */
-  if ((TempF) && (fclose(TempF) == EOF))
-    RetVal = -1;
+  if (TempF)
+  {
+    if (fclose(TempF) == EOF)
+    {
+       if (!ipFlag->Quiet)
+       {
+         ipFlag->error = errno;
+         errstr = strerror(errno);
+         fprintf(stderr, "%s: ", progname);
+         fprintf(stderr, _("Failed to write to temporary output file %s: %s\n"), TempPath, errstr);
+       }
+      RetVal = -1;
+    }
+  }
 
 #ifdef NO_MKSTEMP
   if(fd!=NULL)
@@ -606,17 +665,17 @@ int ConvertUnixToDosNewFile(char *ipInFN, char *ipOutFN, CFlag *ipFlag, char *pr
 #ifndef NO_CHMOD
   if (!RetVal)
   {
-    if (ipFlag->NewFile == 0) /* old file mode */
+    if (ipFlag->NewFile == 0) /* old-file mode */
     {
        RetVal = chmod (TempPath, StatBuf.st_mode); /* set original permissions */
-    } 
+    }
     else
     {
        mask = umask(0); /* get process's umask */
        umask(mask); /* set umask back to original */
        RetVal = chmod(TempPath, StatBuf.st_mode & ~mask); /* set original permissions, minus umask */
     }
-    
+
     if (RetVal)
     {
        if (!ipFlag->Quiet)
@@ -631,9 +690,9 @@ int ConvertUnixToDosNewFile(char *ipInFN, char *ipOutFN, CFlag *ipFlag, char *pr
 #endif
 
 #ifndef NO_CHOWN
-  if (!RetVal && (ipFlag->NewFile == 0))  /* old file mode */
+  if (!RetVal && (ipFlag->NewFile == 0))  /* old-file mode */
   {
-     /* Change owner and group of the the tempory output file to the original file's uid and gid. */
+     /* Change owner and group of the temporary output file to the original file's uid and gid. */
      /* Required when a different user (e.g. root) has write permission on the original file. */
      /* Make sure that the original owner can still access the file. */
      if (chown(TempPath, StatBuf.st_uid, StatBuf.st_gid))
@@ -754,26 +813,32 @@ int ConvertUnixToDosStdio(CFlag *ipFlag, char *progname)
     ipFlag->KeepDate = 0;
     ipFlag->Force = 1;
 
-#if defined(WIN32) && !defined(__CYGWIN__)
+#if defined(_WIN32) && !defined(__CYGWIN__)
 
     /* stdin and stdout are by default text streams. We need
      * to set them to binary mode. Otherwise an LF will
      * automatically be converted to CR-LF on DOS/Windows.
      * Erwin */
 
-    /* 'setmode' was deprecated by MicroSoft
-     * since Visual C++ 2005. Use '_setmode' instead. */
+    /* POSIX 'setmode' was deprecated by MicroSoft since
+     * Visual C++ 2005. Use ISO C++ conformant '_setmode' instead. */
 
-    _setmode(fileno(stdout), O_BINARY);
-    _setmode(fileno(stdin), O_BINARY);
-#elif defined(MSDOS) || defined(__CYGWIN__) || defined(__OS2__)
+    _setmode(_fileno(stdout), _O_BINARY);
+    _setmode(_fileno(stdin), _O_BINARY);
+#elif defined(__MSDOS__) || defined(__CYGWIN__) || defined(__OS2__)
     setmode(fileno(stdout), O_BINARY);
     setmode(fileno(stdin), O_BINARY);
 #endif
 
     read_bom(stdin, &ipFlag->bomtype);
+#ifdef D2U_UNICODE
+    if ((ipFlag->bomtype == FILE_MBS) && (ipFlag->ConvMode == CONVMODE_UTF16LE))
+      ipFlag->bomtype = FILE_UTF16LE;
+    if ((ipFlag->bomtype == FILE_MBS) && (ipFlag->ConvMode == CONVMODE_UTF16BE))
+      ipFlag->bomtype = FILE_UTF16BE;
+#endif
 
-    if ((ipFlag->add_bom) || (ipFlag->bomtype > 0))
+    if ((ipFlag->add_bom) || ((ipFlag->keep_bom) && (ipFlag->bomtype > 0)))
        fprintf(stdout, "%s", "\xEF\xBB\xBF");  /* UTF-8 BOM */
 
 #ifdef D2U_UNICODE
@@ -825,8 +890,14 @@ int main (int argc, char *argv[])
          strcpy(localedir,LOCALEDIR);
       }
    }
+#endif
 
+#if defined(ENABLE_NLS) || (defined(D2U_UNICODE) && !defined(__MSDOS__) && !defined(_WIN32) && !defined(__OS2__))
+/* setlocale() is also needed for nl_langinfo() */
    setlocale (LC_ALL, "");
+#endif
+
+#ifdef ENABLE_NLS
    bindtextdomain (PACKAGE, localedir);
    textdomain (PACKAGE);
 #endif
@@ -836,7 +907,7 @@ int main (int argc, char *argv[])
   ArgIdx = 0;
   CanSwitchFileMode = 1;
   ShouldExit = 0;
-  pFlag = (CFlag*)malloc(sizeof(CFlag));  
+  pFlag = (CFlag*)malloc(sizeof(CFlag));
   pFlag->NewFile = 0;
   pFlag->Quiet = 0;
   pFlag->KeepDate = 0;
@@ -852,6 +923,7 @@ int main (int argc, char *argv[])
   pFlag->bomtype = FILE_MBS;
 #endif
   pFlag->add_bom = 0;
+  pFlag->keep_bom = 1;
 
   if ( ((ptr=strrchr(argv[0],'/')) == NULL) && ((ptr=strrchr(argv[0],'\\')) == NULL) )
     ptr = argv[0];
@@ -877,6 +949,8 @@ int main (int argc, char *argv[])
         PrintUsage(progname);
         return(pFlag->error);
       }
+      else if ((strcmp(argv[ArgIdx],"-b") == 0) || (strcmp(argv[ArgIdx],"--keep-bom") == 0))
+        pFlag->keep_bom = 1;
       else if ((strcmp(argv[ArgIdx],"-k") == 0) || (strcmp(argv[ArgIdx],"--keepdate") == 0))
         pFlag->KeepDate = 1;
       else if ((strcmp(argv[ArgIdx],"-f") == 0) || (strcmp(argv[ArgIdx],"--force") == 0))
@@ -889,6 +963,11 @@ int main (int argc, char *argv[])
         pFlag->NewLine = 1;
       else if ((strcmp(argv[ArgIdx],"-m") == 0) || (strcmp(argv[ArgIdx],"--add-bom") == 0))
         pFlag->add_bom = 1;
+      else if ((strcmp(argv[ArgIdx],"-r") == 0) || (strcmp(argv[ArgIdx],"--remove-bom") == 0))
+      {
+        pFlag->keep_bom = 0;
+        pFlag->add_bom = 0;
+      }
       else if ((strcmp(argv[ArgIdx],"-S") == 0) || (strcmp(argv[ArgIdx],"--skip-symlink") == 0))
         pFlag->Follow = SYMLINK_SKIP;
       else if ((strcmp(argv[ArgIdx],"-F") == 0) || (strcmp(argv[ArgIdx],"--follow-symlink") == 0))
@@ -935,6 +1014,12 @@ int main (int argc, char *argv[])
         pFlag->ConvMode = CONVMODE_865;
       else if (strcmp(argv[ArgIdx],"-1252") == 0)
         pFlag->ConvMode = CONVMODE_1252;
+#ifdef D2U_UNICODE
+      else if ((strcmp(argv[ArgIdx],"-ul") == 0) || (strcmp(argv[ArgIdx],"--assume-utf16le") == 0))
+        pFlag->ConvMode = CONVMODE_UTF16LE;
+      else if ((strcmp(argv[ArgIdx],"-ub") == 0) || (strcmp(argv[ArgIdx],"--assume-utf16be") == 0))
+        pFlag->ConvMode = CONVMODE_UTF16BE;
+#endif
       else if ((strcmp(argv[ArgIdx],"-c") == 0) || (strcmp(argv[ArgIdx],"--convmode") == 0))
       {
         if (++ArgIdx < argc)
@@ -982,7 +1067,7 @@ int main (int argc, char *argv[])
         if (!CanSwitchFileMode)
         {
           fprintf(stderr,"%s: ",progname);
-          fprintf(stderr, _("target of file %s not specified in new file mode\n"), argv[ArgIdx-1]);
+          fprintf(stderr, _("target of file %s not specified in new-file mode\n"), argv[ArgIdx-1]);
           pFlag->error = 1;
           ShouldExit = 1;
           pFlag->stdio_mode = 0;
@@ -996,7 +1081,7 @@ int main (int argc, char *argv[])
         if (!CanSwitchFileMode)
         {
           fprintf(stderr,"%s: ",progname);
-          fprintf(stderr, _("target of file %s not specified in new file mode\n"), argv[ArgIdx-1]);
+          fprintf(stderr, _("target of file %s not specified in new-file mode\n"), argv[ArgIdx-1]);
           pFlag->error = 1;
           ShouldExit = 1;
           pFlag->stdio_mode = 0;
@@ -1089,9 +1174,9 @@ int main (int argc, char *argv[])
             {
               fprintf(stderr,"%s: ",progname);
               if (pFlag->FromToMode == FROMTO_UNIX2MAC)
-                fprintf(stderr, _("converting file %s to file %s in Mac format ...\n"), argv[ArgIdx-1], argv[ArgIdx]);
+                fprintf(stderr, _("converting file %s to file %s in Mac format...\n"), argv[ArgIdx-1], argv[ArgIdx]);
               else
-                fprintf(stderr, _("converting file %s to file %s in DOS format ...\n"), argv[ArgIdx-1], argv[ArgIdx]);
+                fprintf(stderr, _("converting file %s to file %s in DOS format...\n"), argv[ArgIdx-1], argv[ArgIdx]);
             }
             if (RetVal)
             {
@@ -1169,9 +1254,9 @@ int main (int argc, char *argv[])
           {
             fprintf(stderr,"%s: ",progname);
             if (pFlag->FromToMode == FROMTO_UNIX2MAC)
-              fprintf(stderr, _("converting file %s to Mac format ...\n"), argv[ArgIdx]);
+              fprintf(stderr, _("converting file %s to Mac format...\n"), argv[ArgIdx]);
             else
-              fprintf(stderr, _("converting file %s to DOS format ...\n"), argv[ArgIdx]);
+              fprintf(stderr, _("converting file %s to DOS format...\n"), argv[ArgIdx]);
           }
           if (RetVal)
           {
@@ -1196,7 +1281,7 @@ int main (int argc, char *argv[])
   if (!CanSwitchFileMode)
   {
     fprintf(stderr,"%s: ",progname);
-    fprintf(stderr, _("target of file %s not specified in new file mode\n"), argv[ArgIdx-1]);
+    fprintf(stderr, _("target of file %s not specified in new-file mode\n"), argv[ArgIdx-1]);
     pFlag->error = 1;
   }
   return (pFlag->error);
